/*
*********************************************************************************************************
*********************************************************************************************************
7 June 2017

This do-file produces the tables and figures that appear in the section "The Interplay between Tax Avoidance and Evasion" in the paper:

"Tax Evasion and Inequality" (Annette Alstadsæter, Niels Johannesen and Gabriel Zucman)

The do-file has the following parts:

Part 0: prepares datasets
 - A: dataset with measures of disclosed wealth
 - B: dynamic dataset that includes hidden wealth
 
Part 1: creates new variables
 - A: general variabes
 - B: controls
 - C: outcomes
 - D: event-study variables
 
 Part 2: runs event-study regressions (Table 4 + Figure 10 + Figure 11)
 
 Part 3: produces summary statistics comparing disclsoers and non-disclosers (Table 3)
 
 Part 4: produces cross-sectional regressions for 2007 (Table 5)
 
 The do-file starts with the data files "big`yr'.dta" that are documented elsewhere.
 
*********************************************************************************************************
*********************************************************************************************************
*/


/*** set parameters ***/
clear
set more off
cap log close
set matsize 1000

    global prog   "\\...\CLEAN\prog"
	global data   "\\...\CLEAN\data"
    global temp   "\\...\data\no-backup"
	global graphs "\\...\CLEAN\data"
	
log using  $prog\AvoidanceCLEAN_2017_09_05.log, replace


 
*********************************************************************************************************
*********************************************************************************************************
************************************** 0. Prepare datasets***********************************************
*********************************************************************************************************
*********************************************************************************************************


********************************************************************************************
******************************* 0A. Disclosed wealth ***************************************
********************************************************************************************

/*** Create dynamic evader dataset ***/
foreach yr in 01 02 03 04 05 06 07 08 09 10 11 12 13 {
use $data\big`yr'.dta, clear
keep if vd_evader==1
cap drop year
gen year=20`yr'
save $temp\evaderinfo`yr'_IND.dta, replace
}

use $temp\evaderinfo01_IND.dta, clear
foreach yr in 02 03 04 05 06 07 08 09 10 11 12 13 {
append using $temp\evaderinfo`yr'_IND.dta
}

/* Clean dataset  */
replace da_wealth=0 if da_wealth==.
rename vd_taxed_disclosed_wealth vd_wealth

/* Recode two cases with missing status */
replace vd_case_closed=1 if vd_case_closed~=1 & vd_case_dropped~=1 & vd_case_in_process~=1 & vd_wealth>0 & vd_wealth~=.
replace vd_case_in_process=1 if vd_case_closed~=1 & vd_case_dropped~=1 & vd_case_in_process~=1 & (vd_wealth==0 | vd_wealth==.)

/* ad hoc fix of the problems stepping up to market wealth */
* going forward this only affects imputed disclosure estimates of those without decision *
replace mwealth = taxwealth if mwealth < taxwealth & taxwealth~=. 

 
/***  Compute disclosure wealth based on corrections	***/
/* Initiate new variables */
gen disclosed_wealth07C = .
gen total_assets07C = .
gen total_wealth07C = .

/* Define discloser types based on case status*/
gen disclosertype = .
replace disclosertype =1 if vd_case_closed==1 & vd_case_dropped~=1
replace disclosertype =3 if vd_case_in_process==1 & vd_case_dropped~=1 & disclosertype==.
replace disclosertype =4 if vd_case_dropped==1

/* Measure of hidden wealth  */
by ID, sort: egen tempmaxi = max(da_wealth) if  year<=vd_year_of_contact 
by ID, sort: egen tempmaxi2 = mean(tempmaxi) 
replace disclosed_wealth07C = tempmaxi2 if (disclosertype==1 | disclosertype==2) & year==2007
replace total_wealth07C = mwealth - da_wealth + disclosed_wealth07C if (disclosertype==1 | disclosertype==2) & year==2007
gen off2totwealthC = disclosed_wealth07C / total_wealth07C if year==2007 
gen off2totassetsC = disclosed_wealth07C / (total_wealth07C + d_debt) if year==2007 
sum off2totassetsC if year==2007, d
global offwealthratioC = r(mean)
replace disclosed_wealth07C = (mwealth+d_debt)*$offwealthratioC if disclosertype==3 & year==2007
replace total_wealth07C = mwealth + disclosed_wealth07C if disclosertype==3 & year==2007
replace disclosed_wealth07C = 0 if disclosertype==4 & year==2007
replace total_wealth07C = mwealth if disclosertype==4 & year==2007

/* Step up to market value */
replace disclosed_wealth07C = disclosed_wealth07C / 0.85

 
/*** Prepare for merge with main dataset ***/
/* save for big files / analysis */
keep if year==2007
keep ID disclosed_wealth07C total_wealth07C disclosertype
sort ID
save $data\hiddenwealth_vd_IND.dta, replace

 
 
********************************************************************************************
********************************* 0B. Main dataset *****************************************
********************************************************************************************
 
/*** construct dynamic dataset with hidden wealth ***/
/* construct annual datasets */
foreach yr in 02 03 04 05 06 07 08 09 10 11 12 13 {
use $data\big`yr'.dta, clear
keep year ID ind_male ind_marital ind_foreign ind_children ind_age ind_status ind_emigrates_thisyear ind_county mwealth i_* avoid* da_wealth taxwealth tax_wealth vd_* tax_all p_netwealth a_housing_condo a_housing_leisure a_f_housing d_debt md_debt ma_equity avoid_holding2_currentfound avoid_holding2_currentown a_shares_nonreg a_foreignshares a_shares_reg a_foreignshares a_f_shares a_deposits a_f_deposits  a_cash a_bonds_reg a_f_bonds a_movables a_pension a_business_prop di_f_capinc di_income avoid_80reduction
drop if mwealth==.
cap drop rank_w
cumul  mwealth, gen(rank_w)
save $temp\avoidance_ind`yr'.dta, replace
}

/* combine annual datasets */
use $temp\avoidance_ind02.dta, clear
foreach yr in 03 04 05 06 07 08 09 10 11 12 13 {
append using $temp\avoidance_ind`yr'.dta
}

/* merge on hidden wealth */
sort ID
merge m:1 ID using $data\hiddenwealth_vd_IND.dta, keep(match master)
replace disclosed_wealth07C=0 if disclosed_wealth07C==.
rename disclosed_wealth07C vd_hidden_wealth
drop _merge
sort ID year
save $temp\avoidance_all_ind.dta, replace

/* Drop individuals in bottom 90% of the 2007 wealth distribution whose ID ends in 0, 1, ..., 8 */
* (i.e., keep only those whose ID ends in 9)
keep if year == 2007
keep ID rank_w 
rename rank_w rank07
save $temp\rank07.dta, replace
use $temp\avoidance_all_ind.dta, clear
merge m:1 ID using $temp\rank07.dta, keep(match master)
assert ID == round(ID)
drop if vd_evader == 0 & (rank07 < 0.9 | rank07 == .) & mod(ID, 10) < 9
gen weight = 1
replace weight = 10 if vd_evader == 0 & (rank07 < 0.9 | rank07 == .)



*********************************************************************************************************
*********************************************************************************************************
************************************ 1. Generate new variables ******************************************
*********************************************************************************************************
*********************************************************************************************************

*********************************************************************************************
********************************* A. General variables **************************************
*********************************************************************************************

/* generate new wealth concept */
gen alltaxwealth = taxwealth 
replace alltaxwealth  = taxwealth + vd_hidden_wealth - da_wealth if (disclosertype==1 | disclosertype==2) & year<vd_year_of_contact
replace alltaxwealth  = taxwealth + vd_hidden_wealth if disclosertype==3 & year<vd_year_of_contact


/* CHECK that all individuals have constant discloser status */
 gen temp=1
 by ID, sort: egen evaderyears1 = sum(temp)
 by ID, sort: egen evaderyears2 = sum(vd_evader)
 tab year if evaderyears2<evaderyears1 & evaderyears2>0 & evaderyears2~=.
 drop if evaderyears2<evaderyears1 & evaderyears2>0 & evaderyears2~=.
 drop temp

/* define variables indicating whether observations are balanced */
gen balanced = 0
replace balanced = 1 if evaderyears1==12
gen all = 1

/* define variables indicating whether there is a decision */
gen decision = 1
replace decision = 0 if vd_case_dropped==1 | vd_case_in_process==1

/* define variables indicating whether the evader is in top 1% */
gen top1pct = 0
replace top1pct = 1 if rank_w>=0.99

/* construct residence status */
gen livingresident = 0
replace livingresident = 1 if ind_status==1
 
/*drop observations with no year*/
drop if year==.

*** throw away dropped disclosure cases ***
drop if vd_evader==1 & vd_case_dropped==1


*********************************************************************************************
********************************* B. Control variables **************************************
*********************************************************************************************

*** AGE CONTROLS ***
*** define age groups: 3 groups (20-40, 40-60, 60-) and 6 groups (20-30, 30-40, 40-50 and so on) ***
generate  temp = .
replace temp = 1 if ind_age>=20 & ind_age<30 & year==2007
replace temp = 2 if ind_age>=30 & ind_age<40 & year==2007
replace temp = 3 if ind_age>=40 & ind_age<50 & year==2007
replace temp = 4 if ind_age>=50 & ind_age<60 & year==2007
replace temp = 5 if ind_age>=60 & ind_age<70 & year==2007
replace temp = 6 if ind_age>=70 & ind_age~=. & year==2007
by ID, sort: egen age6group07 = sum(temp)
drop temp

*** WEALTH CONTROLS ***
*** NOTE: control for Taxable Wealth (including hidden)
*** define wealth groups:  10 groups of claimed wealth where the thresholds correspond to deciles in distrubution within disclosers ***
*** => same number of disclosers assigned to each wealth group ***
global wealthvar mwealth
 _pctile $wealthvar if vd_evader==1 & year==2007, p(10, 20, 30, 40, 50, 60, 70, 80, 90)
 gen wealth10group07 = .
 replace wealth10group07 = 1 if $wealthvar<=r(r1) & $wealthvar~=.    & year==2007
 replace wealth10group07 = 2 if $wealthvar<=r(r2) & $wealthvar>r(r1) & year==2007
 replace wealth10group07 = 3 if $wealthvar<=r(r3) & $wealthvar>r(r2) & year==2007
 replace wealth10group07 = 4 if $wealthvar<=r(r4) & $wealthvar>r(r3) & year==2007
 replace wealth10group07 = 5 if $wealthvar<=r(r5) & $wealthvar>r(r4) & year==2007
 replace wealth10group07 = 6 if $wealthvar<=r(r6) & $wealthvar>r(r5) & year==2007
 replace wealth10group07 = 7 if $wealthvar<=r(r7) & $wealthvar>r(r6) & year==2007
 replace wealth10group07 = 8 if $wealthvar<=r(r8) & $wealthvar>r(r7) & year==2007
 replace wealth10group07 = 9 if $wealthvar<=r(r9) & $wealthvar>r(r8) & year==2007
 replace wealth10group07 = 10 if $wealthvar>r(r9) & $wealthvar~=.    & year==2007
 rename wealth10group07 tempwealth10
 by ID, sort: egen wealth10group07 = mean(tempwealth10)
  
  
 *** INCOME CONTROLS ***
 *** define income groups:  10 groups of income where the thresholds correspond to deciles in distrubution within disclosers ***
 *** => same number of disclosers assigned to each wealth group ***
 _pctile i_inckg if vd_evader==1 & year==2007, p(10, 20, 30, 40, 50, 60, 70, 80, 90)
 gen income10group07 = .
 replace income10group07 = 1 if i_inckg<=r(r1) & i_inckg~=. & year==2007
 replace income10group07 = 2 if i_inckg<=r(r2) & i_inckg>r(r1) & year==2007
 replace income10group07 = 3 if i_inckg<=r(r3) & i_inckg>r(r2) & year==2007
 replace income10group07 = 4 if i_inckg<=r(r4) & i_inckg>r(r3) & year==2007
 replace income10group07 = 5 if i_inckg<=r(r5) & i_inckg>r(r4) & year==2007
 replace income10group07 = 6 if i_inckg<=r(r6) & i_inckg>r(r5) & year==2007
 replace income10group07 = 7 if i_inckg<=r(r7) & i_inckg>r(r6) & year==2007
 replace income10group07 = 8 if i_inckg<=r(r8) & i_inckg>r(r7) & year==2007
 replace income10group07 = 9 if i_inckg<=r(r9) & i_inckg>r(r8) & year==2007
 replace income10group07 = 10 if i_inckg>r(r9) & i_inckg~=. & year==2007
 rename income10group07 tempincome10
 by ID, sort: egen income10group07 = mean(tempincome10)
 
 
 *** EQUITY CONTROLS - LEVEL ***
  *** controls ***
 _pctile ma_equity if vd_evader==1 & year==2007, p(10, 20, 30, 40, 50, 60, 70, 80, 90)
 gen equity10group07 = .
 replace equity10group07 = 1 if ma_equity<=r(r1) & ma_equity~=. & year==2007
 replace equity10group07 = 2 if ma_equity<=r(r2) & ma_equity>r(r1) & year==2007
 replace equity10group07 = 3 if ma_equity<=r(r3) & ma_equity>r(r2) & year==2007
 replace equity10group07 = 4 if ma_equity<=r(r4) & ma_equity>r(r3) & year==2007
 replace equity10group07 = 5 if ma_equity<=r(r5) & ma_equity>r(r4) & year==2007
 replace equity10group07 = 6 if ma_equity<=r(r6) & ma_equity>r(r5) & year==2007
 replace equity10group07 = 7 if ma_equity<=r(r7) & ma_equity>r(r6) & year==2007
 replace equity10group07 = 8 if ma_equity<=r(r8) & ma_equity>r(r7) & year==2007
 replace equity10group07 = 9 if ma_equity<=r(r9) & ma_equity>r(r8) & year==2007
 replace equity10group07 = 10 if ma_equity>r(r9) & ma_equity~=. & year==2007
 rename equity10group07 tempequity10
 by ID, sort: egen equity10group07 = mean(tempequity10)
  
 *** EQUITY CONTROLS - SHARE ***
  *** controls ***
  gen equityshare = ma_equity / (taxwealth + d_debt)
 _pctile equityshare if vd_evader==1 & year==2007, p(10, 20, 30, 40, 50, 60, 70, 80, 90)
 gen equitysh10group07 = .
 replace equitysh10group07 = 1 if equityshare<=r(r1) & equityshare~=. & year==2007
 replace equitysh10group07 = 2 if equityshare<=r(r2) & equityshare>r(r1) & year==2007
 replace equitysh10group07 = 3 if equityshare<=r(r3) & equityshare>r(r2) & year==2007
 replace equitysh10group07 = 4 if equityshare<=r(r4) & equityshare>r(r3) & year==2007
 replace equitysh10group07 = 5 if equityshare<=r(r5) & equityshare>r(r4) & year==2007
 replace equitysh10group07 = 6 if equityshare<=r(r6) & equityshare>r(r5) & year==2007
 replace equitysh10group07 = 7 if equityshare<=r(r7) & equityshare>r(r6) & year==2007
 replace equitysh10group07 = 8 if equityshare<=r(r8) & equityshare>r(r7) & year==2007
 replace equitysh10group07 = 9 if equityshare<=r(r9) & equityshare>r(r8) & year==2007
 replace equitysh10group07 = 10 if equityshare>r(r9) & equityshare~=. & year==2007
 rename equitysh10group07 tempequityshare10
 by ID, sort: egen equitysh10group07 = mean(tempequityshare10)
 

 *** HOUSING CONTROLS - SHARE ***
  *** controls ***
  gen housingshare = (a_housing_condo + a_housing_leisure + a_f_housing) / (taxwealth + d_debt)
 _pctile housingshare if vd_evader==1 & year==2007, p(10, 20, 30, 40, 50, 60, 70, 80, 90)
 gen housingsh10group07 = .
 replace housingsh10group07 = 1 if housingshare<=r(r1) & housingshare~=. & year==2007
 replace housingsh10group07 = 2 if housingshare<=r(r2) & housingshare>r(r1) & year==2007
 replace housingsh10group07 = 3 if housingshare<=r(r3) & housingshare>r(r2) & year==2007
 replace housingsh10group07 = 4 if housingshare<=r(r4) & housingshare>r(r3) & year==2007
 replace housingsh10group07 = 5 if housingshare<=r(r5) & housingshare>r(r4) & year==2007
 replace housingsh10group07 = 6 if housingshare<=r(r6) & housingshare>r(r5) & year==2007
 replace housingsh10group07 = 7 if housingshare<=r(r7) & housingshare>r(r6) & year==2007
 replace housingsh10group07 = 8 if housingshare<=r(r8) & housingshare>r(r7) & year==2007
 replace housingsh10group07 = 9 if housingshare<=r(r9) & housingshare>r(r8) & year==2007
 replace housingsh10group07 = 10 if housingshare>r(r9) & housingshare~=. & year==2007
 rename housingsh10group07 temphousing10
 by ID, sort: egen housingsh10group07 = mean(temphousing10)
  
 
 *** CONTROLS FOR COUNTY ***
 gen tempcounty07 = ind_county if year==2007
 by ID, sort: egen county07 = mean(tempcounty07)
 
 
*********************************************************************************************
********************************* C. Outcomes and more **************************************
*********************************************************************************************

* No taxable wealth
gen avoid_notaxwealth = (taxwealth == 0)
sum avoid_notaxwealth, d
tab avoid_notaxwealth vd_evader
tab year avoid_notaxwealth if vd_evader == 1 

* No income*
gen avoid_noincome = .
replace avoid_noincome = 1 if i_inckg<=0
replace avoid_noincome = 0 if i_inckg>0 & i_inckg~=.
sum avoid_noincome, d

* Taxable return to capital*
replace i_housing=0 if i_housing==.
replace i_housing_gain=0 if i_housing_gain==.
gen avoid_taxablereturn = .
replace avoid_taxablereturn = (i_interests + i_div + i_kg_shares + i_bonds + i_otherfin + i_f_capinc + i_housing + i_housing_gain) / (mwealth - md_debt)  
sum avoid_taxablereturn, d

* Ratio of taxable wealth to market wealth*
gen avoid_twealth2mwealth = .
replace avoid_twealth2mwealth = (taxwealth + d_debt) / (mwealth - md_debt)
sum avoid_twealth2mwealth , d

* Ratio of wealth tax to taxable wealth
gen avoid_wtax2twealth = .
replace avoid_wtax2twealth = tax_wealth / taxwealth 
sum avoid_wtax2twealth , d

* Majority owner of dividend maximise firm in 2005
sum avoid_divmax05_prof_infirm, d

* Majority owner holding company at some point 04-08*
sum avoid_holding, d 

* Majority own holding 2005*
d avoid_holding_establ_05 avoid_holding2_establ_05, fullname
sum avoid_holding_establ_05, d
sum avoid_holding2_establ_05

* Establishes majority own holding before 2009* 
sum avoid_holding_establ_pre09 avoid_holding2_establ_pre09, d
 
* No capital income*
gen avoid_nocapincome = .
replace avoid_nocapincome = 1 if (i_interests + i_div + i_kg_shares + i_bonds + i_otherfin + i_f_capinc + i_housing + i_housing_gain)<=0
replace avoid_nocapincome = 0 if (i_interests + i_div + i_kg_shares + i_bonds + i_otherfin + i_f_capinc + i_housing + i_housing_gain)>0 
sum avoid_nocapincome, d

* No wage income*
gen avoid_nowageincome = .
replace avoid_nowageincome = 1 if (i_wage + i_business)<=0
replace avoid_nowageincome = 0 if (i_wage + i_business)>0 
sum avoid_nowageincome, d

* Total tax *
gen log_tax_all = log(tax_all)

* Claimed wealth *
gen log_p_netwealth = log(p_netwealth)

* Final taxable wealth *
gen log_taxwealth = log(taxwealth)

* Total income *
gen log_i_inckg = log(i_inckg)

* Share of housing in total wealth *
gen housing = a_housing_condo + a_housing_leisure + a_f_housing
gen log_housing = log(housing)
gen avoid_housingshare = housing / (taxwealth + d_debt)
gen dum_raisehousing = .
sort ID year
by ID: replace dum_raisehousing = 1 if housing>housing[_n-1] & housing~=. & year==year[_n-1]+1 & ID==ID[_n-1]
by ID: replace dum_raisehousing = 0 if housing<=housing[_n-1] & housing[_n-1]~=. & year==year[_n-1]+1 & ID==ID[_n-1]
gen dum_raisehousingsh = .
sort ID year
by ID: replace dum_raisehousingsh = 1 if avoid_housingshare>avoid_housingshare[_n-1] & avoid_housingshare~=. & year==year[_n-1]+1 & ID==ID[_n-1]
by ID: replace dum_raisehousingsh = 0 if avoid_housingshare<=avoid_housingshare[_n-1] & avoid_housingshare[_n-1]~=. & year==year[_n-1]+1 & ID==ID[_n-1]

* Market wealth *
gen log_mwealth = log(mwealth)

* Effective tax rate *
gen avoid_taxpaid2inc = tax_all / i_inckg if i_inckg > 0
replace avoid_taxpaid2inc = 0 if avoid_taxpaid2inc < 0
replace avoid_taxpaid2inc = 1 if avoid_taxpaid2inc > 1

* Log of capital income *
gen log_capincome = log(i_interests + i_div + i_kg_shares + i_bonds + i_otherfin + i_f_capinc + i_housing + i_housing_gain)
gen capincome = i_interests + i_div + i_kg_shares + i_bonds + i_otherfin + i_f_capinc + i_housing + i_housing_gain

* Pays no taxes *
gen avoid_zerotaxes = 0
replace avoid_zerotaxes=1 if tax_all<=0

* Emigration *
gen avoid_emigrate = ind_emigrates_thisyear

* Unlisted shares *
gen log_unlistedshares = log(a_shares_nonreg)
gen avoid_unlistedsecshare = a_shares_nonreg / (taxwealth + d_debt)
gen dum_hasunlisted = 0
replace dum_hasunlisted = 1 if a_shares_nonreg>0 & a_shares_nonreg~=.
gen dum_raiseunlisted = .
sort ID year
by ID: replace dum_raiseunlisted = 1 if a_shares_nonreg>a_shares_nonreg[_n-1] & a_shares_nonreg~=. & year==year[_n-1]+1 & ID==ID[_n-1]
by ID: replace dum_raiseunlisted = 0 if a_shares_nonreg<=a_shares_nonreg[_n-1] & a_shares_nonreg[_n-1]~=. & year==year[_n-1]+1 & ID==ID[_n-1]
gen dum_raiseunlistedsh = .
sort ID year
by ID: replace dum_raiseunlistedsh = 1 if avoid_unlistedsecshare>avoid_unlistedsecshare[_n-1] & avoid_unlistedsecshare~=. & year==year[_n-1]+1 & ID==ID[_n-1]
by ID: replace dum_raiseunlistedsh = 0 if avoid_unlistedsecshare<=avoid_unlistedsecshare[_n-1] & avoid_unlistedsecshare[_n-1]~=. & year==year[_n-1]+1 & ID==ID[_n-1]
gen dum_halfsharesunlisted = (a_shares_nonreg / (a_shares_nonreg + a_shares_reg + a_foreignshares) >= 0.5 )
replace dum_halfsharesunlisted = 0 if dum_halfsharesunlisted == .


* Debt *
gen log_debt = log(d_debt)
gen debtshare = d_debt / (taxwealth + d_debt)
gen dum_raisedebt = .
sort ID year
by ID: replace dum_raisedebt = 1 if d_debt>d_debt[_n-1] & d_debt~=. & year==year[_n-1]+1 & ID==ID[_n-1]
by ID: replace dum_raisedebt = 0 if d_debt<=d_debt[_n-1] & d_debt[_n-1]~=. & year==year[_n-1]+1 & ID==ID[_n-1]
gen dum_raisedebtsh = .
sort ID year
by ID: replace dum_raisedebtsh = 1 if debtshare>debtshare[_n-1] & debtshare~=. & year==year[_n-1]+1 & ID==ID[_n-1]
by ID: replace dum_raisedebtsh = 0 if debtshare<=debtshare[_n-1] & debtshare[_n-1]~=. & year==year[_n-1]+1 & ID==ID[_n-1]

* Interactions with leverage
gen dum_raisedebtandhouse = dum_raisedebt*dum_raisehousing
gen dum_raisedebtandunlistedeq = dum_raisedebt*dum_raiseunlisted

* Increase tax payments*
gen dum_raisetaxpaid = .
sort ID year
by ID: replace dum_raisetaxpaid = 1 if tax_all>tax_all[_n-1] & tax_all~=. & year==year[_n-1]+1 & ID==ID[_n-1]
by ID: replace dum_raisetaxpaid = 0 if tax_all<=tax_all[_n-1] & tax_all[_n-1]~=. & year==year[_n-1]+1 & ID==ID[_n-1]

* Add more outcomes *
gen nochangeintaxwealth = (p_netwealth == taxwealth)
gen changeintaxwealth1 = (taxwealth - p_netwealth)/(0.5*(taxwealth + p_netwealth))
gen y = (taxwealth - p_netwealth)
gen changeintaxwealth2 = log(y+(y^2+1)^(0.5))
sum changeintaxwealth1, d
foreach var in a_shares_reg a_shares_nonreg a_foreignshares a_f_shares a_deposits a_f_deposits  a_cash a_bonds_reg a_f_bonds a_movables a_pension a_business_prop d_debt housing {
gen nlog_`var'=log(`var')
gen nhas_`var'=(`var'~=. & `var'~=0)
sort ID year
gen lag_`var'=.
by ID: replace lag_`var' = `var'[_n-1] if year==year[_n-1]+1 & ID==ID[_n-1]
gen nraise_`var'=(`var'>lag_`var' & `var'~=.)
}
drop lag_*


* Winsorize non-dummy outcomes *
foreach var in log_tax_all log_p_netwealth log_taxwealth log_i_inckg log_capincome log_unlistedshares log_housing log_debt log_mwealth avoid_housingshare avoid_unlistedsecshare debtshare avoid_twealth2mwealth avoid_wtax2twealth avoid_taxpaid2inc avoid_taxablereturn housing {
cap drop w`var'
gen w`var'=`var'
forvalues yr=2002/2013 {
sum `var' if year==`yr', d
replace w`var'=r(p99) if `var'>r(p99) & `var'~=. & year==`yr'
replace w`var'=r(p1) if `var'<r(p1) & `var'~=. & year==`yr'
}
}

* Construct p_income (claimed income) *
gen p_income1 = i_inckg - di_f_capinc
gen log_p_income1 = log(p_income1)

* Construct p_tax (claimed tax liabilities) *
gen p_tax4 = tax_all
gen da_wealth2 = da_wealth
replace da_wealth2 = 0 if da_wealth2 ==.
replace p_tax4 = max(0, tax_all - 0.02276 * da_wealth2) 
replace p_tax4 = max(0, tax_all - 0.01776 * da_wealth2) if avoid_80reduction == 1
gen log_p_tax4 = log(p_tax4)

* Construct p_tax_true (tax liabilities incuding those on undisclosed offshore wealth) *
gen tax_disclosure = 0
replace tax_disclosure = max(0, 0.02276 * vd_hidden_wealth) if vd_evader==1
replace tax_disclosure = max(0, 0.01776 * vd_hidden_wealth) if vd_evader==1 & avoid_80reduction == 1
gen p_tax_true = p_tax4
replace p_tax_true = p_tax_true + tax_disclosure if vd_evader==1 & year<vd_year_of_contact & vd_year_of_contact~=.
gen log_p_tax_true = log(p_tax_true)

* construct new meaure of taxable wealth where housing is winsorized *
gen taxwealth_whouse = taxwealth - housing + whousing
gen log_taxwealth_whouse = log(taxwealth_whouse)

*CHECK: is there a problem with non-integer disclosure years*
tab vd_year_of_contact
replace vd_year_of_contact = . if vd_year_of_contact~=. & vd_year_of_contact~=int(vd_year_of_contact)



*********************************************************************************************
******************************** D. Event-study variables ***********************************
*********************************************************************************************

* Event-time variables: event is first contact *
gen eventtime_0 = 0
replace eventtime_0 = 1 if year == vd_year_of_contact & vd_evader==1
forvalues t=1/15 {
gen eventtime_p`t' = 0
gen eventtime_m`t' = 0
}
forvalues x = 2001/2016 {
forvalues t=1/15 {
replace eventtime_m`t' = 1 if year==`x'-`t' & vd_evader==1 & vd_year_of_contact==`x'
replace eventtime_p`t' = 1 if year==`x'+`t' & vd_evader==1 & vd_year_of_contact==`x'
}
}

* dummies for pre- and post-disclosure *
gen predisclosure = 0
replace predisclosure = 1 if vd_evader==1 & (vd_year_of_contact>=year | vd_year_of_contact==.)
gen postdisclosure = 0
replace postdisclosure = 1 if vd_evader==1 & (vd_year_of_contact<=year | vd_year_of_contact==.)


*CHECK that event time dummies are properly specificed*
tab vd_year_of_contact if vd_evader==1
forvalues year=2007/2016 {
display `year'
sum eventtime* if vd_evader==1 & vd_year_of_contact==`year'
sum eventtime* if vd_evader==0 & vd_year_of_contact==`year'
}
*
sum eventtime* if vd_evader==0


/*** Save dataset ****/
save $temp\avoidance_ind.dta, replace


*/

*********************************************************************************************************
*********************************************************************************************************
************************************* 2. Dynamic regressions ********************************************
*********************************************************************************************************
*********************************************************************************************************

use $temp\avoidance_ind.dta, clear


*** DEFINE VARIOUS BATTERIES OF OF CONTROLS ***
global controls1 "i.age6group07#i.year i.wealth10group07#i.year i.income10group07#i.year"
global controls2 "i.age6group07#i.year i.wealth10group07#i.year i.income10group07#i.year i.housingsh10group#i.year"
global controls3 "i.age6group07#i.year i.wealth10group07#i.year i.income10group07#i.year i.housingsh10group#i.year i.equitysh10group#i.year"
global controls4 "i.age6group07#i.year i.wealth10group07#i.year i.income10group07#i.year i.housingsh10group#i.year i.equitysh10group#i.year i.county07#i.year"

*** DEFINE LIST OF OUTCOMES ***
#delimit;

global outcomes_prepost 
"log_p_netwealth 
log_p_income1 
log_p_tax4 
avoid_emigrate 
avoid_holding2_currentfound 
log_unlistedshares 
log_housing 
avoid_nocapincome 
";

global outcomes_dynamic  
"log_p_netwealth 
log_p_income1 
log_p_tax4
";

global outcomes_truetaxliab
"log_p_tax_true 
";

#delimit cr


*** LIVING RESIDENTS ***
foreach outcome in /*$outcomes_prepost*/ $outcomes_truetaxliab { 
use $temp\avoidance_ind.dta, clear
keep if livingresident == 1
egen tempevader = group(ID) if vd_evader==1
sum tempevader 
global noevaders=r(max)
areg  `outcome' eventtime_m15 eventtime_m14 eventtime_m13 eventtime_m12 eventtime_m11 eventtime_m10 eventtime_m9 eventtime_m8 eventtime_m7 eventtime_m6 eventtime_m5 eventtime_m4 eventtime_m3 /*eventtime_m2*/ eventtime_m1 eventtime_0 eventtime_p1 eventtime_p2 eventtime_p3 eventtime_p4 eventtime_p5 eventtime_p6 eventtime_p7 eventtime_p8 eventtime_p9 eventtime_p10 eventtime_p11 eventtime_p12 eventtime_p13 eventtime_p14 eventtime_p15 i.year $controls1, a(ID) cluster(ID)
do $prog\MakeNiceGraph.do
keep if eventtime>=-5 & eventtime<=4
twoway (connect pointest eventtime) (rcap upbound lowbound eventtime), xtitle("event time") ytitle("level relative to event year") title("Outcome: `outcome'") note("Year and individual FE: YES" "Controls: 10 wealth groups, 10 income groups and 6 age groups" "Observations: `e(N)' ; evaders: $noevaders") xline(-2, lpattern(dash) lcolor(black)) yline(0, lpattern(dash) lcolor(black)) scheme(s1mono)
graph export $graphs\AvoidanceIND02A_Resds_`outcome'_controls1.pdf, as(pdf) replace
graph save $graphs\AvoidanceIND02A_Resds_`outcome'_controls1.gph, replace
}



*** PRE_POST REGRESSIONS ***
cap erase "$graphs\AvoidanceIND02A.txt"
cap erase "$graphs\AvoidanceIND02A.xml"
cap erase "$graphs\AvoidanceIND02A_Resds.txt"
cap erase "$graphs\AvoidanceIND02A_Resds.xml"
use $temp\avoidance_ind.dta, clear
gen eventtime_post = (eventtime_0==1 | eventtime_p1==1 | eventtime_p2==1)

foreach outcome in avoid_emigrate  /*$outcomes_prepost*/ { 
*ALL*
areg  `outcome' eventtime_m15 eventtime_m14 eventtime_m13 eventtime_m12 eventtime_m11 eventtime_m10 eventtime_m9 eventtime_m8 eventtime_m7 eventtime_m6 eventtime_m5 eventtime_m1 eventtime_post eventtime_p3 eventtime_p4 eventtime_p5 eventtime_p6 eventtime_p7 eventtime_p8 eventtime_p9 eventtime_p10 eventtime_p11 eventtime_p12 eventtime_p13 eventtime_p14 eventtime_p15 i.year $controls1, a(ID) cluster(ID)
outreg2 using "$graphs\AvoidanceIND02A", append excel dec(4)  ctitle("`outcome'", "All") addtext(year FE, YES, indiv FE, YES, wealth, YES, income, YES, age, YES, housing share, NO, equity share, NO, county FE, NO) keep(eventtime_post)

*LIVING RESIDENTS*
keep if livingresident == 1
areg  `outcome' eventtime_m15 eventtime_m14 eventtime_m13 eventtime_m12 eventtime_m11 eventtime_m10 eventtime_m9 eventtime_m8 eventtime_m7 eventtime_m6 eventtime_m5 eventtime_m1 eventtime_post eventtime_p3 eventtime_p4 eventtime_p5 eventtime_p6 eventtime_p7 eventtime_p8 eventtime_p9 eventtime_p10 eventtime_p11 eventtime_p12 eventtime_p13 eventtime_p14 eventtime_p15 i.year $controls1, a(ID) cluster(ID)
outreg2 using "$graphs\AvoidanceIND02A_Resds", append excel dec(4)  ctitle("`outcome'", "Living resds") addtext(year FE, YES, indiv FE, YES, wealth, YES, income, YES, age, YES, housing share, NO, equity share, NO, county FE, NO) keep(eventtime_post)

}



*********************************************************************************************************
*********************************************************************************************************
************************************* 3. Summary Stats **************************************************
*********************************************************************************************************
*********************************************************************************************************

*** SUMMARY STATS ***
*weighted*
use $temp\avoidance_ind.dta, clear
keep if year==2007
gen obs=1
collapse (sum) obs (mean) ind_male ind_marital ind_foreign ind_children ind_age tax_all p_netwealth alltaxwealth i_inckg capincome avoid_divmax05_prof_infirm avoid_holding2_currentown avoid_noincome avoid_notaxwealth avoid_nocapincome avoid_nowageincome avoid_zerotaxes avoid_80reduction dum_hasunlisted  [pw=weight], by(vd_evader)
export excel using "$graphs\Avoidance00_SummaryStats07weight", firstrow(variables) replace

*unweighted*
use $temp\avoidance_ind.dta, clear
keep if year==2007
gen obs=1
collapse (sum) obs (mean) ind_male ind_marital ind_foreign ind_children ind_age tax_all p_netwealth alltaxwealth i_inckg capincome avoid_divmax05_prof_infirm avoid_holding2_currentown avoid_noincome avoid_notaxwealth avoid_nocapincome avoid_nowageincome avoid_zerotaxes avoid_80reduction dum_hasunlisted  , by(vd_evader)
export excel using "$graphs\Avoidance00_SummaryStats07unweight", firstrow(variables) replace



***********************************************************************************************************************
***********************************************************************************************************************
****************************************** 4. Cross-sectional regressions *********************************************
***********************************************************************************************************************
***********************************************************************************************************************

*loop over wealth concepts*
global wealthvar "alltaxwealth"

cap erase "$graphs\Avoidance00_CrossSection_$wealthvar.txt"
cap erase "$graphs\Avoidance00_CrossSection_$wealthvar.xml"

use $temp\avoidance_ind.dta, clear
gen log_alltaxwealth = log(alltaxwealth)
keep if year==2007
 
 *25 wealth groups*
 cap drop wealth25group07
 _pctile $wealthvar if vd_evader==1 & year==2007, p(4, 8, 12, 16, 20, 24, 28, 32, 36, 40, 44, 48, 52, 56, 60, 64, 68, 72, 76, 80, 84, 88, 92, 96)
 gen wealth25group07 = .
 replace wealth25group07 = 1 if $wealthvar<=r(r1) & $wealthvar~=.    & year==2007
 replace wealth25group07 = 25 if $wealthvar>r(r24) & $wealthvar~=.    & year==2007
 forvalues quan = 1/24 {
 global low = `quan'
 global high = `quan' + 1
 replace wealth25group07 = $high if $wealthvar<=r(r$high) & $wealthvar>r(r$low) & year==2007
 }
 rename wealth25group07 tempwealth25
 by ID, sort: egen wealth25group07 = mean(tempwealth25)

 
 *50 wealth groups*
 cap drop wealth50group07
 _pctile $wealthvar if vd_evader==1 & year==2007, p(2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 86, 88, 90, 92, 94, 96, 98)
 gen wealth50group07 = .
 replace wealth50group07 = 1 if $wealthvar<=r(r1) & $wealthvar~=.    & year==2007
 replace wealth50group07 = 50 if $wealthvar>r(r49) & $wealthvar~=.    & year==2007
 forvalues quan = 1/49 {
 global low = `quan'
 global high = `quan' + 1
 replace wealth50group07 = $high if $wealthvar<=r(r$high) & $wealthvar>r(r$low) & year==2007
 }
 rename wealth50group07 tempwealth50
 by ID, sort: egen wealth50group07 = mean(tempwealth50)

 *100 wealth groups*
 cap drop wealth100group07
 _pctile $wealthvar if vd_evader==1 & year==2007, p(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99)
 gen wealth100group07 = .
 replace wealth100group07 = 1 if $wealthvar<=r(r1) & $wealthvar~=.    & year==2007
 replace wealth100group07 = 100 if $wealthvar>r(r99) & $wealthvar~=.    & year==2007
 forvalues quan = 1/99 {
 global low = `quan'
 global high = `quan' + 1
 replace wealth100group07 = $high if $wealthvar<=r(r$high) & $wealthvar>r(r$low) & year==2007
 }
 rename wealth100group07 tempwealth100
 by ID, sort: egen wealth100group07 = mean(tempwealth100)

 
*** regressions ***
global controls1 "i.age6group07#i.year i.wealth10group07#i.year i.income10group07#i.year"
global controls1a "i.age6group07#i.year i.wealth25group07#i.year i.income10group07#i.year"
global controls1b "i.age6group07#i.year i.wealth50group07#i.year i.income10group07#i.year"
global controls1c "i.age6group07#i.year i.wealth100group07#i.year i.income10group07#i.year"
global controls2 "i.age6group07#i.year i.wealth10group07#i.year i.income10group07#i.year i.housingsh10group#i.year"
global controls3 "i.age6group07#i.year i.wealth10group07#i.year i.income10group07#i.year i.housingsh10group#i.year i.equitysh10group#i.year"
global controls4 "i.age6group07#i.year i.wealth10group07#i.year i.income10group07#i.year i.housingsh10group#i.year i.equitysh10group#i.year i.county07#i.year"
global controls4c "i.age6group07#i.year i.wealth100group07#i.year i.income10group07#i.year i.housingsh10group#i.year i.equitysh10group#i.year i.county07#i.year"


*loop over outcomes*
foreach outcome in log_alltaxwealth avoid_divmax05_prof_infirm avoid_holding2_currentown avoid_80reduction {

*2007 only*
reg `outcome' vd_evader $controls1c  if year==2007
outreg2 using "$graphs\Avoidance00_CrossSection_$wealthvar", append excel dec(4)  ctitle("`outcome'", "All individuals", "2007") addtext(age, 6 groups, wealth, 100 groups, income, 10 groups, housing share, NO, equity share, NO, regions, NO) keep(vd_evader)
}
*

clear
log close

