********************************************************************************
********************************************************************************
***** Construct measures of hidden wealth for 						************
***** 	- disclosers												************
***** 	- evaders caught in crackdown								************
********************************************************************************
********************************************************************************

/*******************************************************************************
This part of the do-file constructs meaures 2007-hidden wealth for 
 - "voluntary disclosers" (VD)
 - "evaders caught in audits" (PIP, BKP)
	
Section A deals with disclosers where we apply three methods to compute hidden wealth:
 A) using actual corrections in 2007 if unbroken line of corrections and otherwise average corrections in years around disclosure 
 B) using information from vd_wealth (divide by 6)
 C) using maximum correction across all pre-disclosure years
	
Section B deals with evaders caught in audits and uses methods equivalent to A) 
and C) above to compute hidden wealth
	
Under all approaches, offshore wealth is imputed for disclosers whose cases are 
in progress
			 
The final datasets contains a variable "disclosertype" essentially indicates how 
to obtain a measure of total wealth - in some cases mwealth already includes the 
correction, in other cases not.
*******************************************************************************/

**********************************************************************
**********************  A. DISCLOSERS 		**************************
**********************************************************************
 
**********************************************************************
***********  A0. Create dynamic evader dataset and clear 		******
**********************************************************************

/*** Create dynamic evader dataset ***/
foreach yr in 01 02 03 04 05 06 07 08 09 10 11 12 13 {
use $temp\big`yr'hhold.dta, clear
keep if vd_evader==1
cap drop year
gen year=20`yr'
save $temp\evaderinfo`yr'.dta, replace
}

use $temp\evaderinfo01.dta, clear
foreach yr in 02 03 04 05 06 07 08 09 10 11 12 13 {
append using $temp\evaderinfo`yr'.dta
}

/*** Clean dataset  ***/
replace da_wealth=0 if da_wealth==.
rename vd_taxed_disclosed_wealth vd_wealth

/*** Recode two cases with missing status ***/
replace vd_case_closed=1 if vd_case_closed~=1 & vd_case_dropped~=1 & vd_case_in_process~=1 & vd_wealth>0 & vd_wealth~=.
replace vd_case_in_process=1 if vd_case_closed~=1 & vd_case_dropped~=1 & vd_case_in_process~=1 & (vd_wealth==0 | vd_wealth==.)

/*** ad hoc fix of the problems stepping up to market wealth ***/
* going forward this only affects imputed disclosure estimates of those without decision *
replace mwealth = taxwealth if mwealth < taxwealth & taxwealth~=. 


********************************************************************************
****  A1. Compute disclosure and 2007-wealth based on corrections		********
********************************************************************************

/* Initiate new variables */
gen disclosed_wealth07A = .
gen total_assets07A = .
gen total_wealth07A = .
gen disclosertype = .

/* Compute disclosed wealth for those with:
		- "closed and non-dropped case" 
		- "unbroken line of (reasonably sized) corrections from 2007 to disclosure time" */	
by ind_hhold, sort: egen temp_maxoffshore = max(da_wealth) if year<vd_year_of_contact & year>vd_year_of_contact-4 
by ind_hhold, sort: egen maxoffshore = mean(temp_maxoffshore)
gen correction = 0
replace correction = 1 if da_wealth>0 & da_wealth~=. & da_wealth>maxoffshore*0.5
by ind_hhold, sort: egen temp_allcorrections = min(correction) if year<vd_year_of_contact & year>=2007
by ind_hhold, sort: egen allcorrections = mean(temp_allcorrections)
gen temp07 = da_wealth if year==2007 
by ind_hhold, sort: egen correction07 = mean(temp07)
global condition1 "vd_case_closed==1 & vd_case_dropped~=1 & correction07>0 & allcorrections==1"
replace disclosed_wealth07A = correction07 if $condition1 & year==2007
replace total_wealth07A = mwealth if $condition1 & year==2007
replace disclosertype=1 if $condition1

/* Compute disclosed wealth for those with:
		- "closed and non-dropped case" 
		- "not unbroken line of corrections from 2007 to disclosure" */
by ind_hhold, sort: egen tempavg = mean(da_wealth) if year<vd_year_of_contact & year>vd_year_of_contact-4 & correction==1
by ind_hhold, sort: egen correctionavg = mean(tempavg)
replace correctionavg = 0 if correctionavg==.
global condition2 "vd_case_closed==1 & vd_case_dropped~=1 & disclosertype==."
replace disclosed_wealth07A = correctionavg if $condition2 & year==2007 
replace total_wealth07A = mwealth + disclosed_wealth07A - da_wealth if $condition2 & year==2007
replace disclosertype=2 if $condition2


/* Compute disclosed wealth for those with:
		- "case in process" */
gen off2totwealthA = disclosed_wealth07A / total_wealth07A if year==2007
gen off2totassetsA = disclosed_wealth07A / (total_wealth07A + d_debt) if year==2007
sum off2totassetsA, d
global offwealthratioA = r(mean)
global condition3 "vd_case_in_process==1 & vd_case_dropped~=1 & disclosertype==."
replace disclosed_wealth07A = (mwealth+d_debt)*$offwealthratioA  if $condition3 & year==2007
replace total_wealth07A = mwealth + disclosed_wealth07A if $condition3 & year==2007
replace disclosertype=3 if $condition3
sum off2totassetsA, d

/* Label dropped cases: */
global condition4 "vd_case_dropped==1"
replace disclosed_wealth07A = 0  if $condition4 & year==2007
replace total_wealth07A = mwealth if $condition4 & year==2007
replace disclosertype=4 if $condition4
sum off2totassetsA, d

/* Step up to market value */
replace disclosed_wealth07A = disclosed_wealth07A / 0.85

********************************************************************************
*******  A2. Compute disclosure and 2007-wealth based on vd_wealth		********
********************************************************************************

/* Initiate new variables */
gen disclosed_wealth07B = .
gen total_assets07B = .
gen total_wealth07B = .

/*** Simpler measure of hidden wealth based on vd_wealth ***/
replace vd_wealth  = 0 if vd_wealth  == .
replace disclosed_wealth07B = vd_wealth / 6 if (disclosertype==1 | disclosertype==2) & year==2007
replace total_wealth07B = mwealth - da_wealth + disclosed_wealth07B if (disclosertype==1 | disclosertype==2) & year==2007
gen off2totwealthB = disclosed_wealth07B / total_wealth07B if year==2007 
gen off2totassetsB = disclosed_wealth07B / (total_wealth07B + d_debt) if year==2007 
sum off2totassetsB if year==2007, d
global offwealthratioB = r(mean)
replace disclosed_wealth07B = (mwealth+d_debt)*$offwealthratioB  if disclosertype==3 & year==2007
replace total_wealth07B = mwealth + disclosed_wealth07B if disclosertype==3 & year==2007
replace disclosed_wealth07B = 0 if disclosertype==4 & year==2007
replace total_wealth07B = mwealth if disclosertype==4 & year==2007

/*** Step up to market value ***/
replace disclosed_wealth07B = disclosed_wealth07B / 0.85

****************************************************************************************
*******  A3. Compute disclosure and 2007-wealth based on largest correction		********
****************************************************************************************

/* Initiate new variables */
gen disclosed_wealth07C = .
gen total_assets07C = .
gen total_wealth07C = .

/*** Simpler measure of hidden wealth based on vd_wealth ***/
by ind_hhold, sort: egen tempmaxi = max(da_wealth) if  year<=vd_year_of_contact 
by ind_hhold, sort: egen tempmaxi2 = mean(tempmaxi) 
replace disclosed_wealth07C = tempmaxi2 if (disclosertype==1 | disclosertype==2) & year==2007
replace total_wealth07C = mwealth - da_wealth + disclosed_wealth07C if (disclosertype==1 | disclosertype==2) & year==2007
gen off2totwealthC = disclosed_wealth07C / total_wealth07C if year==2007 
gen off2totassetsC = disclosed_wealth07C / (total_wealth07C + d_debt) if year==2007 
sum off2totassetsC if year==2007, d
global offwealthratioC = r(mean)
replace disclosed_wealth07C = (mwealth+d_debt)*$offwealthratioC if disclosertype==3 & year==2007
replace total_wealth07C = mwealth + disclosed_wealth07C if disclosertype==3 & year==2007
replace disclosed_wealth07C = 0 if disclosertype==4 & year==2007
replace total_wealth07C = mwealth if disclosertype==4 & year==2007

/*** Step up to market value ***/
replace disclosed_wealth07C = disclosed_wealth07C / 0.85


****************************************************************************
***************** A4. Prepare for merge with main dataset *******************
****************************************************************************

* save for big files / analysis *
keep if year==2007
keep ind_hhold disclosed_wealth07A total_wealth07A disclosed_wealth07B total_wealth07B disclosed_wealth07C total_wealth07C disclosertype
sort ind_hhold
save $data\hiddenwealth_vd.dta, replace


**********************************************************************
**********************  B. PIP EVADERS 		**************************
**********************************************************************

**********************************************************************
***********  B0. Create dynamic evader dataset and clear 		******
**********************************************************************

/*** Create dynamic PIP evader dataset with all info***/
foreach yr in 01 02 03 04 05 06 07 08 09 10 11 12 13 {
use $temp\big`yr'hhold.dta, clear
keep if aud_insample==1
cap drop year
gen year=20`yr'
save $temp\PIPinfo`yr'.dta, replace
}

use $temp\PIPinfo01.dta, clear
foreach yr in 02 03 04 05 06 07 08 09 10 11 12 13 {
append using $temp\PIPinfo`yr'.dta
}
sort ind_hhold year
replace da_wealth = 0 if da_wealth==.

/*** Save dataset ***/
save $temp\FullPIPinfo.dta, replace


********************************************************************************
****  B1. Compute hidden wealth and 2007-wealth based on corrections	********
********************************************************************************

/* Initiate new variables */
gen hidden_wealth07A = .
gen total_assets07A = .
gen total_wealth07A = .
gen evadertype = .

/* Compute hidden wealth for those with:
		- "closed case" 
		- "unbroken line of (reasonably sized) corrections from 2007 to audit time" */	
by ind_hhold, sort: egen temp_maxoffshore = max(da_wealth) if year<aud_year_start & year>aud_year_start-4 
by ind_hhold, sort: egen maxoffshore = mean(temp_maxoffshore)
gen correction = 0
replace correction = 1 if da_wealth>0 & da_wealth~=. & da_wealth>maxoffshore*0.5
by ind_hhold, sort: egen temp_allcorrections = min(correction) if year<aud_year_start & year>=2007
by ind_hhold, sort: egen allcorrections = mean(temp_allcorrections)
gen temp07 = da_wealth if year==2007 
by ind_hhold, sort: egen correction07 = mean(temp07)
global condition1 "aud_year_decision~=. & correction07>0 & allcorrections==1"
replace hidden_wealth07A = correction07 if $condition1 & year==2007
replace total_wealth07A = mwealth if $condition1 & year==2007
replace evadertype=1 if $condition1

/* Compute hidden wealth for those with:
		- "closed case" 
		- "not unbroken line of corrections from 2007 to audit time" */
by ind_hhold, sort: egen tempavg = mean(da_wealth) if year<aud_year_start & year>aud_year_start-4 & correction==1
by ind_hhold, sort: egen correctionavg = mean(tempavg)
replace correctionavg = 0 if correctionavg==.
global condition2 "aud_year_decision~=. & evadertype==."
replace hidden_wealth07A = correctionavg if $condition2 & year==2007 
replace total_wealth07A = mwealth + hidden_wealth07A - da_wealth if $condition2 & year==2007
replace evadertype=2 if $condition2


/* Compute hidden wealth for those with:
		- "case in process" */
gen off2totwealthA = hidden_wealth07A / total_wealth07A if year==2007
gen off2totassetsA = hidden_wealth07A / (total_wealth07A + d_debt) if year==2007
sum off2totassetsA, d
global offwealthratioA = r(mean)
global condition3 "aud_year_decision==. & evadertype==."
replace hidden_wealth07A = (mwealth+d_debt)*$offwealthratioA  if $condition3 & year==2007
replace total_wealth07A = mwealth + hidden_wealth07A if $condition3 & year==2007
replace evadertype=3 if $condition3


/* Step up to market value */
replace hidden_wealth07A = hidden_wealth07A / 0.85


****************************************************************************************
*******  B2. Compute hidden wealth and 2007-wealth based on largest correction	 *******
****************************************************************************************

/* Initiate new variables */
gen hidden_wealth07C = .
gen total_assets07C = .
gen total_wealth07C = .

/*** Simpler measure of hidden wealth based on largest correction ***/
by ind_hhold, sort: egen tempmaxi = max(da_wealth) if  year<=aud_year_start 
by ind_hhold, sort: egen tempmaxi2 = mean(tempmaxi) 
replace hidden_wealth07C = tempmaxi2 if (evadertype==1 | evadertype==2) & year==2007
replace total_wealth07C = mwealth - da_wealth + hidden_wealth07C if (evadertype==1 | evadertype==2) & year==2007
gen off2totwealthC = hidden_wealth07C / total_wealth07C if year==2007 
gen off2totassetsC = hidden_wealth07C / (total_wealth07C + d_debt) if year==2007 
sum off2totwealthC if year==2007, d
global offwealthratioC = r(mean)
replace hidden_wealth07C = (mwealth+d_debt)*$offwealthratioC if evadertype==3 & year==2007
replace total_wealth07C = mwealth + hidden_wealth07C if evadertype==3 & year==2007

/*** Step up to market value ***/
replace hidden_wealth07C = hidden_wealth07C / 0.85


****************************************************************************
***************** B3. Prepare for merge with main dataset *******************
****************************************************************************

* save for analysis / big files *
keep if year==2007
keep ind_hhold hidden_wealth07A total_wealth07A hidden_wealth07C total_wealth07C evadertype
sort ind_hhold
save $data\hiddenwealth_pip.dta, replace


